@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -14,7 +17,7 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-skylight", "1.1.97", __name__[0:-6], "cdk-skylight@1.1.97.jsii.tgz"
+    "cdk-skylight", "1.1.492", __name__[0:-6], "cdk-skylight@1.1.492.jsii.tgz"
 )
 
 __all__ = [
